aboutsummaryrefslogtreecommitdiff
path: root/nuttx/configs/kwikstik-k40
diff options
context:
space:
mode:
authorpatacongo <patacongo@7fd9a85b-ad96-42d3-883c-3090e2eb8679>2012-01-25 20:17:59 +0000
committerpatacongo <patacongo@7fd9a85b-ad96-42d3-883c-3090e2eb8679>2012-01-25 20:17:59 +0000
commit85a7bbb39f3caaaaeab34393acc32d24520322f7 (patch)
tree7dddd582f892fceb4d2b93f1202946d7cbeed23b /nuttx/configs/kwikstik-k40
parent5db00d175ca019d26d8aa18da120f6c106dd15b2 (diff)
downloadpx4-firmware-85a7bbb39f3caaaaeab34393acc32d24520322f7.tar.gz
px4-firmware-85a7bbb39f3caaaaeab34393acc32d24520322f7.tar.bz2
px4-firmware-85a7bbb39f3caaaaeab34393acc32d24520322f7.zip
Massive name change USB STRG -> USB MSC
git-svn-id: https://nuttx.svn.sourceforge.net/svnroot/nuttx/trunk@4334 7fd9a85b-ad96-42d3-883c-3090e2eb8679
Diffstat (limited to 'nuttx/configs/kwikstik-k40')
-rwxr-xr-xnuttx/configs/kwikstik-k40/ostest/defconfig44
-rwxr-xr-xnuttx/configs/kwikstik-k40/src/Makefile4
-rwxr-xr-xnuttx/configs/kwikstik-k40/src/up_usbmsc.c (renamed from nuttx/configs/kwikstik-k40/src/up_usbstrg.c)16
3 files changed, 32 insertions, 32 deletions
diff --git a/nuttx/configs/kwikstik-k40/ostest/defconfig b/nuttx/configs/kwikstik-k40/ostest/defconfig
index 3b0eb3ca0..57ffe91c0 100755
--- a/nuttx/configs/kwikstik-k40/ostest/defconfig
+++ b/nuttx/configs/kwikstik-k40/ostest/defconfig
@@ -733,40 +733,40 @@ CONFIG_USBSER_TXBUFSIZE=512
#
# USB Storage Device Configuration
#
-# CONFIG_USBSTRG
+# CONFIG_USBMSC
# Enable compilation of the USB storage driver
-# CONFIG_USBSTRG_EP0MAXPACKET
+# CONFIG_USBMSC_EP0MAXPACKET
# Max packet size for endpoint 0
-# CONFIG_USBSTRG_EPBULKOUT and CONFIG_USBSTRG_EPBULKIN
+# CONFIG_USBMSC_EPBULKOUT and CONFIG_USBMSC_EPBULKIN
# The logical 7-bit address of a hardware endpoints that support
# bulk OUT and IN operations
-# CONFIG_USBSTRG_NWRREQS and CONFIG_USBSTRG_NRDREQS
+# CONFIG_USBMSC_NWRREQS and CONFIG_USBMSC_NRDREQS
# The number of write/read requests that can be in flight
-# CONFIG_USBSTRG_BULKINREQLEN and CONFIG_USBSTRG_BULKOUTREQLEN
+# CONFIG_USBMSC_BULKINREQLEN and CONFIG_USBMSC_BULKOUTREQLEN
# The size of the buffer in each write/read request. This
# value needs to be at least as large as the endpoint
# maxpacket and ideally as large as a block device sector.
-# CONFIG_USBSTRG_VENDORID and CONFIG_USBSTRG_VENDORSTR
+# CONFIG_USBMSC_VENDORID and CONFIG_USBMSC_VENDORSTR
# The vendor ID code/string
-# CONFIG_USBSTRG_PRODUCTID and CONFIG_USBSTRG_PRODUCTSTR
+# CONFIG_USBMSC_PRODUCTID and CONFIG_USBMSC_PRODUCTSTR
# The product ID code/string
-# CONFIG_USBSTRG_REMOVABLE
+# CONFIG_USBMSC_REMOVABLE
# Select if the media is removable
#
-CONFIG_USBSTRG=n
-CONFIG_USBSTRG_EP0MAXPACKET=64
-CONFIG_USBSTRG_EPBULKOUT=2
-CONFIG_USBSTRG_EPBULKIN=5
-CONFIG_USBSTRG_NRDREQS=2
-CONFIG_USBSTRG_NWRREQS=2
-CONFIG_USBSTRG_BULKINREQLEN=256
-CONFIG_USBSTRG_BULKOUTREQLEN=256
-CONFIG_USBSTRG_VENDORID=0x584e
-CONFIG_USBSTRG_VENDORSTR="NuttX"
-CONFIG_USBSTRG_PRODUCTID=0x5342
-CONFIG_USBSTRG_PRODUCTSTR="USBdev Storage"
-CONFIG_USBSTRG_VERSIONNO=0x0399
-CONFIG_USBSTRG_REMOVABLE=y
+CONFIG_USBMSC=n
+CONFIG_USBMSC_EP0MAXPACKET=64
+CONFIG_USBMSC_EPBULKOUT=2
+CONFIG_USBMSC_EPBULKIN=5
+CONFIG_USBMSC_NRDREQS=2
+CONFIG_USBMSC_NWRREQS=2
+CONFIG_USBMSC_BULKINREQLEN=256
+CONFIG_USBMSC_BULKOUTREQLEN=256
+CONFIG_USBMSC_VENDORID=0x584e
+CONFIG_USBMSC_VENDORSTR="NuttX"
+CONFIG_USBMSC_PRODUCTID=0x5342
+CONFIG_USBMSC_PRODUCTSTR="USBdev Storage"
+CONFIG_USBMSC_VERSIONNO=0x0399
+CONFIG_USBMSC_REMOVABLE=y
#
# Settings for examples/uip
diff --git a/nuttx/configs/kwikstik-k40/src/Makefile b/nuttx/configs/kwikstik-k40/src/Makefile
index 9e0d72258..8c61af8af 100755
--- a/nuttx/configs/kwikstik-k40/src/Makefile
+++ b/nuttx/configs/kwikstik-k40/src/Makefile
@@ -58,8 +58,8 @@ ifeq ($(CONFIG_USBDEV),y)
CSRCS += up_usbdev.c
endif
-ifeq ($(CONFIG_USBSTRG),y)
-CSRCS += up_usbstrg.c
+ifeq ($(CONFIG_USBMSC),y)
+CSRCS += up_usbmsc.c
endif
COBJS = $(CSRCS:.c=$(OBJEXT))
diff --git a/nuttx/configs/kwikstik-k40/src/up_usbstrg.c b/nuttx/configs/kwikstik-k40/src/up_usbmsc.c
index d5dcebf7a..378295cfa 100755
--- a/nuttx/configs/kwikstik-k40/src/up_usbstrg.c
+++ b/nuttx/configs/kwikstik-k40/src/up_usbmsc.c
@@ -1,5 +1,5 @@
/****************************************************************************
- * configs/kwikstik-k40/src/up_usbstrg.c
+ * configs/kwikstik-k40/src/up_usbmsc.c
*
* Copyright (C) 2011 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <spudmonkey@racsa.co.cr>
@@ -56,8 +56,8 @@
/* Configuration ************************************************************/
-#ifndef CONFIG_EXAMPLES_USBSTRG_DEVMINOR1
-# define CONFIG_EXAMPLES_USBSTRG_DEVMINOR1 0
+#ifndef CONFIG_EXAMPLES_USBMSC_DEVMINOR1
+# define CONFIG_EXAMPLES_USBMSC_DEVMINOR1 0
#endif
/* SLOT number(s) could depend on the board configuration */
@@ -96,23 +96,23 @@
****************************************************************************/
/****************************************************************************
- * Name: usbstrg_archinitialize
+ * Name: usbmsc_archinitialize
*
* Description:
* Perform architecture specific initialization
*
****************************************************************************/
-int usbstrg_archinitialize(void)
+int usbmsc_archinitialize(void)
{
/* If examples/usbstrg is built as an NSH command, then SD slot should
* already have been initized in nsh_archinitialize() (see up_nsh.c). In
* this case, there is nothing further to be done here.
*/
-#ifndef CONFIG_EXAMPLES_USBSTRG_BUILTIN
+#ifndef CONFIG_EXAMPLES_USBMSC_BUILTIN
# warning "Missing logic"
-#endif /* CONFIG_EXAMPLES_USBSTRG_BUILTIN */
+#endif /* CONFIG_EXAMPLES_USBMSC_BUILTIN */
return OK;
}
@@ -96,23 +96,23 @@
{
- /* If examples/usbstrg is built as an NSH command, then SD slot should
+ /* If examples/usbmsc is built as an NSH command, then SD slot should
* already have been initized in nsh_archinitialize() (see up_nsh.c). In
* this case, there is nothing further to be done here.